@@ -1,7 +1,6 @@
 """PyTorch Lightning modules for Dynamic Factor Models.
 
-This package provides PyTorch Lightning implementations of DFM and DDFM,
-replacing the legacy NumPy-based implementations.
+This package provides PyTorch Lightning implementations of DFM and DDFM.
 """
 
 from ..ssm.kalman import (
@@ -19,13 +18,16 @@ from .data_module import (
     DFMDataset,
 )
 
+# DFMLightningModule is an internal implementation used by DFMLinear and estimation.py.
+# DDFMLightningModule is defined but not currently used - DDFM class uses DDFMModel directly.
+# These are not part of the public API.
 from .dfm_module import (
-    DFMLightningModule,
+    DFMLightningModule,  # Internal: used by DFMLinear._train_with_lightning()
     DFMTrainingState,
 )
 
 from .ddfm_module import (
-    DDFMLightningModule,
+    DDFMLightningModule,  # Internal: defined but not currently used (DDFM uses DDFMModel)
     DDFMTrainingState,
 )
 
@@ -39,10 +41,10 @@ __all__ = [
     # Data handling
     'DFMDataModule',
     'DFMDataset',
-    # Lightning modules
-    'DFMLightningModule',
+    # Lightning modules (internal implementations)
+    'DFMLightningModule',  # Internal: used by DFMLinear._train_with_lightning()
     'DFMTrainingState',
-    'DDFMLightningModule',
+    'DDFMLightningModule',  # Internal: defined but not currently used
     'DDFMTrainingState',
 ]
 
